// ChonkyFullFileBrowser.tsx
import { forwardRef, memo } from "react";
import {
  StylesProvider,
  createGenerateClassName,
} from "@material-ui/core/styles";

import {
  FileBrowser,
  FileList,
  FileContextMenu,
  FileNavbar,
  FileToolbar,
  setChonkyDefaults,
  FileBrowserHandle,
  FileBrowserProps,
} from "chonky";

import { ChonkyIconFA } from "chonky-icon-fontawesome";

setChonkyDefaults({ iconComponent: ChonkyIconFA });

const muiJSSClassNameGenerator = createGenerateClassName({
  // Seed property is used to add a prefix classes generated by material ui.
  seed: "chonky",
});

export default memo(
  forwardRef((props, ref) => {
    const { onScroll } = props;
    return (
      <StylesProvider generateClassName={muiJSSClassNameGenerator}>
        <FileBrowser ref={ref} {...props}>
          <FileNavbar />
          <FileToolbar />
          <FileList onScroll={onScroll} />
          <FileContextMenu />
        </FileBrowser>
      </StylesProvider>
    );
  }),
);
